@@ -18,15 +18,13 @@
  * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __NAUTILUS_APPLICATION_H__
-#define __NAUTILUS_APPLICATION_H__
+#pragma once
 
 #include <gdk/gdk.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
-#include "nautilus-bookmark-list.h"
-#include "nautilus-window.h"
+#include "nautilus-types.h"
 
 G_BEGIN_DECLS
 #define NAUTILUS_TYPE_APPLICATION (nautilus_application_get_type())
@@ -86,9 +84,6 @@ GtkWidget * nautilus_application_connect_server (NautilusApplication *applicatio
 						 NautilusWindow      *window);
 
 void nautilus_application_search (NautilusApplication *application,
-                                  const gchar         *uri,
-                                  const gchar         *text);
+                                  NautilusQuery       *query);
 void nautilus_application_startup_common (NautilusApplication *application);
 G_END_DECLS
-
-#endif /* __NAUTILUS_APPLICATION_H__ */
