@@ -19,8 +19,7 @@
  * Author: Amos Brocco <amos.brocco@gmail.com>
  */
 
-#ifndef __NAUTILUS_FILE_UNDO_MANAGER_H__
-#define __NAUTILUS_FILE_UNDO_MANAGER_H__
+#pragma once
 
 #include <glib.h>
 #include <glib-object.h>
@@ -52,5 +51,3 @@ void nautilus_file_undo_manager_undo (GtkWindow *parent_window);
 void nautilus_file_undo_manager_redo (GtkWindow *parent_window);
 
 gboolean nautilus_file_undo_manager_is_operating (void);
-
-#endif /* __NAUTILUS_FILE_UNDO_MANAGER_H__ */
