@@ -55,6 +55,8 @@ enum
     PROP_LOADING,
     PROP_SEARCHING,
     PROP_SELECTION,
+    PROP_EXTENSIONS_BACKGROUND_MENU,
+    PROP_TEMPLATES_MENU,
     LAST_PROP
 };
 
@@ -175,6 +177,17 @@ nautilus_places_view_get_property (GObject    *object,
         }
         break;
 
+        /* Collect all unused properties and do nothing. Ideally, this wouldn’t
+         * have to be done in the first place.
+         */
+        case PROP_SEARCHING:
+        case PROP_SELECTION:
+        case PROP_EXTENSIONS_BACKGROUND_MENU:
+        case PROP_TEMPLATES_MENU:
+        {
+        }
+        break;
+
         default:
             G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     }
@@ -353,7 +366,14 @@ nautilus_places_view_class_init (NautilusPlacesViewClass *klass)
     g_object_class_override_property (object_class, PROP_LOADING, "loading");
     g_object_class_override_property (object_class, PROP_SEARCHING, "searching");
     g_object_class_override_property (object_class, PROP_LOCATION, "location");
+    g_object_class_override_property (object_class, PROP_SELECTION, "selection");
     g_object_class_override_property (object_class, PROP_SEARCH_QUERY, "search-query");
+    g_object_class_override_property (object_class,
+                                      PROP_EXTENSIONS_BACKGROUND_MENU,
+                                      "extensions-background-menu");
+    g_object_class_override_property (object_class,
+                                      PROP_TEMPLATES_MENU,
+                                      "templates-menu");
 }
 
 static void
