@@ -16,8 +16,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef NAUTILUS_TAG_MANAGER_H
-#define NAUTILUS_TAG_MANAGER_H
+#pragma once
 
 #include <glib.h>
 #include <glib-object.h>
@@ -52,6 +51,4 @@ void                nautilus_tag_manager_unstar_files       (NautilusTagManager
 gboolean            nautilus_tag_manager_file_is_starred   (NautilusTagManager *self,
                                                              const gchar        *file_name);
 
-G_END_DECLS
-
-#endif
\ No newline at end of file
+G_END_DECLS
\ No newline at end of file
