@@ -1,5 +1,4 @@
-#ifndef NAUTILUS_VIEW_ITEM_MODEL_H
-#define NAUTILUS_VIEW_ITEM_MODEL_H
+#pragma once
 
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -30,7 +29,4 @@ void nautilus_view_item_model_set_item_ui (NautilusViewItemModel *self,
 
 GtkWidget * nautilus_view_item_model_get_item_ui (NautilusViewItemModel *self);
 
-G_END_DECLS
-
-#endif /* NAUTILUS_VIEW_ITEM_MODEL_H */
-
+G_END_DECLS
\ No newline at end of file
